==> django_email_confirm_la-2.3.1-py2.py3-none-any.whl: email_confirm_la/tests/test_views.py <==
# coding: utf-8

from django.contrib.auth import get_user_model
from django.core import mail
from django.test.utils import override_settings

from .base import BaseTestCase
from email_confirm_la.models import EmailConfirmation


class ViewTest(BaseTestCase):

    def setUp(self):
        User = get_user_model()
        self.user_obj = User.objects.create_user(username='kiko_mizuhara')
        self.user_email = 'kiko.mizuhara@gmail.com'
        self.user_email_2 = 'kiko.mizuhara@yahoo.com'

    def test_confirm_email(self):
        User = get_user_model()
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)
        self.assertFalse(response.context['user'].is_authenticated())

        self.user_obj = User.objects.get(id=self.user_obj.id)
        self.assertEqual(self.user_obj.email, self.user_email)

    def test_confirm_email_invalid(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        confirmation.confirmation_key = 'broken'

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)

        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response,
            'email_confirm_la/email_confirmation_fail.html'
        )

    @override_settings(EMAIL_CONFIRM_LA_HTTP_PROTOCOL='https', EMAIL_CONFIRM_LA_DOMAIN='vinta.ws')
    def test_custom_domain(self):
        EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        mail_obj = mail.outbox[0]

        self.assertIn('https://vinta.ws/', mail_obj.body)

    @override_settings(EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME='test_app:your_confirm_email')
    def test_custom_confirm_url_reverse_name(self):
        User = get_user_model()
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)

        self.assertIn('/test_app/your_confirm_email/', url)

        response = self.client.get(url)

        self.assertEqual(response.status_code, 200)

        confirmation = EmailConfirmation.objects.get(id=confirmation.id)
        self.user_obj = User.objects.get(id=self.user_obj.id)

        self.assertEqual(self.user_obj.email, self.user_email)

    @override_settings(EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME='test_app:your_confirm_email')
    def test_custom_template_context_in_email(self):
        EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        mail_obj = mail.outbox[0]

        self.assertIn('the Answer to the Ultimate Question of Life, the Universe, and Everything: 42.', mail_obj.body)

    def test_custom_template_context_in_view(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)

        self.assertContains(response, 'the Answer to the Ultimate Question of Life, the Universe, and Everything: 42.')

    @override_settings(EMAIL_CONFIRM_LA_AUTOLOGIN=True)
    def test_autologin(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)
        self.assertTrue(response.context['user'].is_authenticated())

==> django_email_confirm_la-3.0.0-py2.py3-none-any.whl: email_confirm_la/tests/test_views.py <==
# coding: utf-8

from django.contrib.auth import get_user_model
from django.core import mail
from django.test.utils import override_settings

from .base import BaseTestCase
from email_confirm_la.models import EmailConfirmation


class ViewTest(BaseTestCase):

    def setUp(self):
        User = get_user_model()
        self.user_obj = User.objects.create_user(username='kiko_mizuhara')
        self.user_email = 'kiko.mizuhara@gmail.com'
        self.user_email_2 = 'kiko.mizuhara@yahoo.com'

    def test_confirm_email(self):
        User = get_user_model()
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)
        self.assertFalse(response.context['user'].is_authenticated)

        self.user_obj = User.objects.get(id=self.user_obj.id)
        self.assertEqual(self.user_obj.email, self.user_email)

    def test_confirm_email_invalid(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        confirmation.confirmation_key = 'broken'

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)

        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response,
            'email_confirm_la/email_confirmation_fail.html'
        )

    @override_settings(EMAIL_CONFIRM_LA_HTTP_PROTOCOL='https', EMAIL_CONFIRM_LA_DOMAIN='vinta.ws')
    def test_custom_domain(self):
        EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        mail_obj = mail.outbox[0]

        self.assertIn('https://vinta.ws/', mail_obj.body)

    @override_settings(EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME='test_app:your_confirm_email')
    def test_custom_confirm_url_reverse_name(self):
        User = get_user_model()
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)

        self.assertIn('/test_app/your_confirm_email/', url)

        response = self.client.get(url)

        self.assertEqual(response.status_code, 200)

        confirmation = EmailConfirmation.objects.get(id=confirmation.id)
        self.user_obj = User.objects.get(id=self.user_obj.id)

        self.assertEqual(self.user_obj.email, self.user_email)

    @override_settings(EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME='test_app:your_confirm_email')
    def test_custom_template_context_in_email(self):
        EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        mail_obj = mail.outbox[0]

        self.assertIn('the Answer to the Ultimate Question of Life, the Universe, and Everything: 42.', mail_obj.body)

    def test_custom_template_context_in_view(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)

        self.assertContains(response, 'the Answer to the Ultimate Question of Life, the Universe, and Everything: 42.')

    @override_settings(EMAIL_CONFIRM_LA_AUTOLOGIN=True)
    def test_autologin(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)
        self.assertTrue(response.context['user'].is_authenticated)
